@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1001';
+our $VERSION = '0.1100';
 
 use Moo;
 use MIDI::Simple;
@@ -195,6 +195,15 @@ sub set_time_sig {
 }
 
 
+sub accent_note {
+    my $self = shift;
+    my $volume = shift;
+    $self->score->Volume($volume->[0]);
+    $self->note(@_);
+    $self->score->Volume($volume->[1]);
+}
+
+
 sub write {
     my $self = shift;
     $self->score->write_score( $self->file );
@@ -214,7 +223,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1001
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -434,6 +443,16 @@ Add a 5/8 beat to the score.
 Set the B<signature>, B<beats>, B<divisions>, and the B<score>
 C<time_signature> values based on the given string.
 
+=head2 accent_note
+
+  $d->accent_note([$accent, $resume], $d->sixteenth, $d->snare);
+
+Play an accented note.
+
+For instance, this can be a "ghosted note", where the B<accent> is a
+smaller number (< 50), or an "accented note" that is greater than the
+current (B<resume>) volume.
+
 =head2 write
 
 Output the score to the default F<*.mid> file or one given to the
